@@ -5,8 +5,23 @@ from dataclasses import dataclass
 from functools import partial
 from os import PathLike
 from typing import (
-    IO, TYPE_CHECKING, Any, AnyStr, AsyncIterator, Callable, Generic, Iterable, Iterator, List,
-    Optional, Sequence, Tuple, Union, cast, overload)
+    IO,
+    TYPE_CHECKING,
+    Any,
+    AnyStr,
+    AsyncIterator,
+    Callable,
+    Generic,
+    Iterable,
+    Iterator,
+    List,
+    Optional,
+    Sequence,
+    Tuple,
+    Union,
+    cast,
+    overload,
+)
 
 from .. import to_thread
 from ..abc import AsyncResource
@@ -79,7 +94,7 @@ class AsyncFile(AsyncResource, Generic[AnyStr]):
     async def read(self, size: int = -1) -> AnyStr:
         return await to_thread.run_sync(self._fp.read, size)
 
-    async def read1(self: 'AsyncFile[bytes]', size: int = -1) -> bytes:
+    async def read1(self: "AsyncFile[bytes]", size: int = -1) -> bytes:
         return await to_thread.run_sync(self._fp.read1, size)
 
     async def readline(self) -> AnyStr:
@@ -88,28 +103,36 @@ class AsyncFile(AsyncResource, Generic[AnyStr]):
     async def readlines(self) -> List[AnyStr]:
         return await to_thread.run_sync(self._fp.readlines)
 
-    async def readinto(self: 'AsyncFile[bytes]', b: WriteableBuffer) -> bytes:
+    async def readinto(self: "AsyncFile[bytes]", b: WriteableBuffer) -> bytes:
         return await to_thread.run_sync(self._fp.readinto, b)
 
-    async def readinto1(self: 'AsyncFile[bytes]', b: WriteableBuffer) -> bytes:
+    async def readinto1(self: "AsyncFile[bytes]", b: WriteableBuffer) -> bytes:
         return await to_thread.run_sync(self._fp.readinto1, b)
 
     @overload
-    async def write(self: 'AsyncFile[bytes]', b: ReadableBuffer) -> int: ...
+    async def write(self: "AsyncFile[bytes]", b: ReadableBuffer) -> int:
+        ...
 
     @overload
-    async def write(self: 'AsyncFile[str]', b: str) -> int: ...
+    async def write(self: "AsyncFile[str]", b: str) -> int:
+        ...
 
     async def write(self, b: Union[ReadableBuffer, str]) -> int:
         return await to_thread.run_sync(self._fp.write, b)
 
     @overload
-    async def writelines(self: 'AsyncFile[bytes]', lines: Iterable[ReadableBuffer]) -> None: ...
+    async def writelines(
+        self: "AsyncFile[bytes]", lines: Iterable[ReadableBuffer]
+    ) -> None:
+        ...
 
     @overload
-    async def writelines(self: 'AsyncFile[str]', lines: Iterable[str]) -> None: ...
+    async def writelines(self: "AsyncFile[str]", lines: Iterable[str]) -> None:
+        ...
 
-    async def writelines(self, lines: Union[Iterable[ReadableBuffer], Iterable[str]]) -> None:
+    async def writelines(
+        self, lines: Union[Iterable[ReadableBuffer], Iterable[str]]
+    ) -> None:
         return await to_thread.run_sync(self._fp.writelines, lines)
 
     async def truncate(self, size: Optional[int] = None) -> int:
@@ -126,25 +149,43 @@ class AsyncFile(AsyncResource, Generic[AnyStr]):
 
 
 @overload
-async def open_file(file: Union[str, PathLike, int], mode: OpenBinaryMode,
-                    buffering: int = ..., encoding: Optional[str] = ...,
-                    errors: Optional[str] = ..., newline: Optional[str] = ..., closefd: bool = ...,
-                    opener: Optional[Callable[[str, int], int]] = ...) -> AsyncFile[bytes]:
+async def open_file(
+    file: Union[str, "PathLike[str]", int],
+    mode: OpenBinaryMode,
+    buffering: int = ...,
+    encoding: Optional[str] = ...,
+    errors: Optional[str] = ...,
+    newline: Optional[str] = ...,
+    closefd: bool = ...,
+    opener: Optional[Callable[[str, int], int]] = ...,
+) -> AsyncFile[bytes]:
     ...
 
 
 @overload
-async def open_file(file: Union[str, PathLike, int], mode: OpenTextMode = ...,
-                    buffering: int = ..., encoding: Optional[str] = ...,
-                    errors: Optional[str] = ..., newline: Optional[str] = ..., closefd: bool = ...,
-                    opener: Optional[Callable[[str, int], int]] = ...) -> AsyncFile[str]:
+async def open_file(
+    file: Union[str, "PathLike[str]", int],
+    mode: OpenTextMode = ...,
+    buffering: int = ...,
+    encoding: Optional[str] = ...,
+    errors: Optional[str] = ...,
+    newline: Optional[str] = ...,
+    closefd: bool = ...,
+    opener: Optional[Callable[[str, int], int]] = ...,
+) -> AsyncFile[str]:
     ...
 
 
-async def open_file(file: Union[str, PathLike, int], mode: str = 'r', buffering: int = -1,
-                    encoding: Optional[str] = None, errors: Optional[str] = None,
-                    newline: Optional[str] = None, closefd: bool = True,
-                    opener: Optional[Callable[[str, int], int]] = None) -> AsyncFile:
+async def open_file(
+    file: Union[str, "PathLike[str]", int],
+    mode: str = "r",
+    buffering: int = -1,
+    encoding: Optional[str] = None,
+    errors: Optional[str] = None,
+    newline: Optional[str] = None,
+    closefd: bool = True,
+    opener: Optional[Callable[[str, int], int]] = None,
+) -> AsyncFile[Any]:
     """
     Open a file asynchronously.
 
@@ -153,8 +194,9 @@ async def open_file(file: Union[str, PathLike, int], mode: str = 'r', buffering:
     :return: an asynchronous file object
 
     """
-    fp = await to_thread.run_sync(open, file, mode, buffering, encoding, errors, newline,
-                                  closefd, opener)
+    fp = await to_thread.run_sync(
+        open, file, mode, buffering, encoding, errors, newline, closefd, opener
+    )
     return AsyncFile(fp)
 
 
@@ -170,15 +212,15 @@ def wrap_file(file: IO[AnyStr]) -> AsyncFile[AnyStr]:
 
 
 @dataclass(eq=False)
-class _PathIterator(AsyncIterator['Path']):
-    iterator: Iterator[PathLike]
+class _PathIterator(AsyncIterator["Path"]):
+    iterator: Iterator["PathLike[str]"]
 
-    async def __anext__(self) -> 'Path':
+    async def __anext__(self) -> "Path":
         nextval = await to_thread.run_sync(next, self.iterator, None, cancellable=True)
         if nextval is None:
             raise StopAsyncIteration from None
 
-        return Path(cast(PathLike, nextval))
+        return Path(cast("PathLike[str]", nextval))
 
 
 class Path:
@@ -232,9 +274,11 @@ class Path:
     * :meth:`~pathlib.Path.rglob`
     """
 
-    __slots__ = '_path', '__weakref__'
+    __slots__ = "_path", "__weakref__"
 
-    def __init__(self, *args: Union[str, PathLike]) -> None:
+    __weakref__: Any
+
+    def __init__(self, *args: Union[str, "PathLike[str]"]) -> None:
         self._path: Final[pathlib.Path] = pathlib.Path(*args)
 
     def __fspath__(self) -> str:
@@ -244,7 +288,7 @@ class Path:
         return self._path.__str__()
 
     def __repr__(self) -> str:
-        return f'{self.__class__.__name__}({self.as_posix()!r})'
+        return f"{self.__class__.__name__}({self.as_posix()!r})"
 
     def __bytes__(self) -> bytes:
         return self._path.__bytes__()
@@ -256,26 +300,26 @@ class Path:
         target = other._path if isinstance(other, Path) else other
         return self._path.__eq__(target)
 
-    def __lt__(self, other: 'Path') -> bool:
+    def __lt__(self, other: "Path") -> bool:
         target = other._path if isinstance(other, Path) else other
         return self._path.__lt__(target)
 
-    def __le__(self, other: 'Path') -> bool:
+    def __le__(self, other: "Path") -> bool:
         target = other._path if isinstance(other, Path) else other
         return self._path.__le__(target)
 
-    def __gt__(self, other: 'Path') -> bool:
+    def __gt__(self, other: "Path") -> bool:
         target = other._path if isinstance(other, Path) else other
         return self._path.__gt__(target)
 
-    def __ge__(self, other: 'Path') -> bool:
+    def __ge__(self, other: "Path") -> bool:
         target = other._path if isinstance(other, Path) else other
         return self._path.__ge__(target)
 
-    def __truediv__(self, other: Any) -> 'Path':
+    def __truediv__(self, other: Any) -> "Path":
         return Path(self._path / other)
 
-    def __rtruediv__(self, other: Any) -> 'Path':
+    def __rtruediv__(self, other: Any) -> "Path":
         return Path(other) / self
 
     @property
@@ -295,11 +339,11 @@ class Path:
         return self._path.anchor
 
     @property
-    def parents(self) -> Sequence['Path']:
+    def parents(self) -> Sequence["Path"]:
         return tuple(Path(p) for p in self._path.parents)
 
     @property
-    def parent(self) -> 'Path':
+    def parent(self) -> "Path":
         return Path(self._path.parent)
 
     @property
@@ -318,7 +362,7 @@ class Path:
     def stem(self) -> str:
         return self._path.stem
 
-    async def absolute(self) -> 'Path':
+    async def absolute(self) -> "Path":
         path = await to_thread.run_sync(self._path.absolute)
         return Path(path)
 
@@ -331,7 +375,7 @@ class Path:
     def match(self, path_pattern: str) -> bool:
         return self._path.match(path_pattern)
 
-    def is_relative_to(self, *other: Union[str, PathLike]) -> bool:
+    def is_relative_to(self, *other: Union[str, "PathLike[str]"]) -> bool:
         try:
             self.relative_to(*other)
             return True
@@ -343,31 +387,31 @@ class Path:
         return await to_thread.run_sync(func, self._path, mode)
 
     @classmethod
-    async def cwd(cls) -> 'Path':
+    async def cwd(cls) -> "Path":
         path = await to_thread.run_sync(pathlib.Path.cwd)
         return cls(path)
 
     async def exists(self) -> bool:
         return await to_thread.run_sync(self._path.exists, cancellable=True)
 
-    async def expanduser(self) -> 'Path':
+    async def expanduser(self) -> "Path":
         return Path(await to_thread.run_sync(self._path.expanduser, cancellable=True))
 
-    def glob(self, pattern: str) -> AsyncIterator['Path']:
+    def glob(self, pattern: str) -> AsyncIterator["Path"]:
         gen = self._path.glob(pattern)
         return _PathIterator(gen)
 
     async def group(self) -> str:
         return await to_thread.run_sync(self._path.group, cancellable=True)
 
-    async def hardlink_to(self, target: Union[str, pathlib.Path, 'Path']) -> None:
+    async def hardlink_to(self, target: Union[str, pathlib.Path, "Path"]) -> None:
         if isinstance(target, Path):
             target = target._path
 
         await to_thread.run_sync(os.link, target, self)
 
     @classmethod
-    async def home(cls) -> 'Path':
+    async def home(cls) -> "Path":
         home_path = await to_thread.run_sync(pathlib.Path.home)
         return cls(home_path)
 
@@ -401,11 +445,11 @@ class Path:
     async def is_symlink(self) -> bool:
         return await to_thread.run_sync(self._path.is_symlink, cancellable=True)
 
-    def iterdir(self) -> AsyncIterator['Path']:
+    def iterdir(self) -> AsyncIterator["Path"]:
         gen = self._path.iterdir()
         return _PathIterator(gen)
 
-    def joinpath(self, *args: Union[str, 'PathLike[str]']) -> 'Path':
+    def joinpath(self, *args: Union[str, "PathLike[str]"]) -> "Path":
         return Path(self._path.joinpath(*args))
 
     async def lchmod(self, mode: int) -> None:
@@ -414,24 +458,44 @@ class Path:
     async def lstat(self) -> os.stat_result:
         return await to_thread.run_sync(self._path.lstat, cancellable=True)
 
-    async def mkdir(self, mode: int = 0o777, parents: bool = False,
-                    exist_ok: bool = False) -> None:
+    async def mkdir(
+        self, mode: int = 0o777, parents: bool = False, exist_ok: bool = False
+    ) -> None:
         await to_thread.run_sync(self._path.mkdir, mode, parents, exist_ok)
 
     @overload
-    async def open(self, mode: OpenBinaryMode, buffering: int = ..., encoding: Optional[str] = ...,
-                   errors: Optional[str] = ..., newline: Optional[str] = ...) -> AsyncFile[bytes]:
+    async def open(
+        self,
+        mode: OpenBinaryMode,
+        buffering: int = ...,
+        encoding: Optional[str] = ...,
+        errors: Optional[str] = ...,
+        newline: Optional[str] = ...,
+    ) -> AsyncFile[bytes]:
         ...
 
     @overload
-    async def open(self, mode: OpenTextMode = ..., buffering: int = ...,
-                   encoding: Optional[str] = ..., errors: Optional[str] = ...,
-                   newline: Optional[str] = ...) -> AsyncFile[str]:
+    async def open(
+        self,
+        mode: OpenTextMode = ...,
+        buffering: int = ...,
+        encoding: Optional[str] = ...,
+        errors: Optional[str] = ...,
+        newline: Optional[str] = ...,
+    ) -> AsyncFile[str]:
         ...
 
-    async def open(self, mode: str = 'r', buffering: int = -1, encoding: Optional[str] = None,
-                   errors: Optional[str] = None, newline: Optional[str] = None) -> AsyncFile:
-        fp = await to_thread.run_sync(self._path.open, mode, buffering, encoding, errors, newline)
+    async def open(
+        self,
+        mode: str = "r",
+        buffering: int = -1,
+        encoding: Optional[str] = None,
+        errors: Optional[str] = None,
+        newline: Optional[str] = None,
+    ) -> AsyncFile[Any]:
+        fp = await to_thread.run_sync(
+            self._path.open, mode, buffering, encoding, errors, newline
+        )
         return AsyncFile(fp)
 
     async def owner(self) -> str:
@@ -440,53 +504,62 @@ class Path:
     async def read_bytes(self) -> bytes:
         return await to_thread.run_sync(self._path.read_bytes)
 
-    async def read_text(self, encoding: Optional[str] = None, errors: Optional[str] = None) -> str:
+    async def read_text(
+        self, encoding: Optional[str] = None, errors: Optional[str] = None
+    ) -> str:
         return await to_thread.run_sync(self._path.read_text, encoding, errors)
 
-    def relative_to(self, *other: Union[str, PathLike]) -> 'Path':
+    def relative_to(self, *other: Union[str, "PathLike[str]"]) -> "Path":
         return Path(self._path.relative_to(*other))
 
-    async def readlink(self) -> 'Path':
+    async def readlink(self) -> "Path":
         target = await to_thread.run_sync(os.readlink, self._path)
         return Path(cast(str, target))
 
-    async def rename(self, target: Union[str, pathlib.PurePath, 'Path']) -> 'Path':
+    async def rename(self, target: Union[str, pathlib.PurePath, "Path"]) -> "Path":
         if isinstance(target, Path):
             target = target._path
 
         await to_thread.run_sync(self._path.rename, target)
         return Path(target)
 
-    async def replace(self, target: Union[str, pathlib.PurePath, 'Path']) -> 'Path':
+    async def replace(self, target: Union[str, pathlib.PurePath, "Path"]) -> "Path":
         if isinstance(target, Path):
             target = target._path
 
         await to_thread.run_sync(self._path.replace, target)
         return Path(target)
 
-    async def resolve(self, strict: bool = False) -> 'Path':
+    async def resolve(self, strict: bool = False) -> "Path":
         func = partial(self._path.resolve, strict=strict)
         return Path(await to_thread.run_sync(func, cancellable=True))
 
-    def rglob(self, pattern: str) -> AsyncIterator['Path']:
+    def rglob(self, pattern: str) -> AsyncIterator["Path"]:
         gen = self._path.rglob(pattern)
         return _PathIterator(gen)
 
     async def rmdir(self) -> None:
         await to_thread.run_sync(self._path.rmdir)
 
-    async def samefile(self, other_path: Union[str, bytes, int, pathlib.Path, 'Path']) -> bool:
+    async def samefile(
+        self, other_path: Union[str, bytes, int, pathlib.Path, "Path"]
+    ) -> bool:
         if isinstance(other_path, Path):
             other_path = other_path._path
 
-        return await to_thread.run_sync(self._path.samefile, other_path, cancellable=True)
+        return await to_thread.run_sync(
+            self._path.samefile, other_path, cancellable=True
+        )
 
     async def stat(self, *, follow_symlinks: bool = True) -> os.stat_result:
         func = partial(os.stat, follow_symlinks=follow_symlinks)
         return await to_thread.run_sync(func, self._path, cancellable=True)
 
-    async def symlink_to(self, target: Union[str, pathlib.Path, 'Path'],
-                         target_is_directory: bool = False) -> None:
+    async def symlink_to(
+        self,
+        target: Union[str, pathlib.Path, "Path"],
+        target_is_directory: bool = False,
+    ) -> None:
         if isinstance(target, Path):
             target = target._path
 
@@ -502,23 +575,30 @@ class Path:
             if not missing_ok:
                 raise
 
-    def with_name(self, name: str) -> 'Path':
+    def with_name(self, name: str) -> "Path":
         return Path(self._path.with_name(name))
 
-    def with_stem(self, stem: str) -> 'Path':
+    def with_stem(self, stem: str) -> "Path":
         return Path(self._path.with_name(stem + self._path.suffix))
 
-    def with_suffix(self, suffix: str) -> 'Path':
+    def with_suffix(self, suffix: str) -> "Path":
         return Path(self._path.with_suffix(suffix))
 
     async def write_bytes(self, data: bytes) -> int:
         return await to_thread.run_sync(self._path.write_bytes, data)
 
-    async def write_text(self, data: str, encoding: Optional[str] = None,
-                         errors: Optional[str] = None, newline: Optional[str] = None) -> int:
+    async def write_text(
+        self,
+        data: str,
+        encoding: Optional[str] = None,
+        errors: Optional[str] = None,
+        newline: Optional[str] = None,
+    ) -> int:
         # Path.write_text() does not support the "newline" parameter before Python 3.10
         def sync_write_text() -> int:
-            with self._path.open('w', encoding=encoding, errors=errors, newline=newline) as fp:
+            with self._path.open(
+                "w", encoding=encoding, errors=errors, newline=newline
+            ) as fp:
                 return fp.write(data)
 
         return await to_thread.run_sync(sync_write_text)
